emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] /srv/bzr/emacs/emacs-24 r111079: Document cygwin-convert-f


From: Glenn Morris
Subject: [Emacs-diffs] /srv/bzr/emacs/emacs-24 r111079: Document cygwin-convert-file-name-{to|from}-windows
Date: Wed, 26 Dec 2012 23:55:14 -0800
User-agent: Bazaar (2.5.0)

------------------------------------------------------------
revno: 111079
committer: Glenn Morris <address@hidden>
branch nick: emacs-24
timestamp: Wed 2012-12-26 23:55:14 -0800
message:
  Document cygwin-convert-file-name-{to|from}-windows
  
  * doc/lispref/files.texi (File Names): Mention Cygwin conversion functions.
  
  * src/cygw32.c (Fcygwin_convert_file_name_to_windows)
  (Fcygwin_convert_file_name_from_windows): Doc fixes.
  
  * etc/NEWS: Related markup.
modified:
  doc/lispref/ChangeLog
  doc/lispref/files.texi
  etc/NEWS
  src/ChangeLog
  src/cygw32.c
=== modified file 'doc/lispref/ChangeLog'
--- a/doc/lispref/ChangeLog     2012-12-22 10:12:52 +0000
+++ b/doc/lispref/ChangeLog     2012-12-27 07:55:14 +0000
@@ -1,3 +1,7 @@
+2012-12-27  Glenn Morris  <address@hidden>
+
+       * files.texi (File Names): Mention Cygwin conversion functions.
+
 2012-12-22  Martin Rudalics  <address@hidden>
 
        * windows.texi (Selecting Windows): Reword description of

=== modified file 'doc/lispref/files.texi'
--- a/doc/lispref/files.texi    2012-12-05 22:27:56 +0000
+++ b/doc/lispref/files.texi    2012-12-27 07:55:14 +0000
@@ -1699,12 +1699,20 @@
 can operate on file names that do not refer to an existing file or
 directory.
 
address@hidden cygwin-convert-file-name-from-windows
address@hidden cygwin-convert-file-name-to-windows
address@hidden MS-Windows file-name syntax
address@hidden converting file names from/to MS-Windows syntax
   On MS-DOS and MS-Windows, these functions (like the function that
 actually operate on files) accept MS-DOS or MS-Windows file-name syntax,
 where backslashes separate the components, as well as Unix syntax; but
 they always return Unix syntax.  This enables Lisp programs to specify
 file names in Unix syntax and work properly on all systems without
-change.
address@hidden MS-Windows versions of Emacs compiled for the Cygwin
+environment, you can use the functions
address@hidden and
address@hidden to convert between the
+two file-name syntaxes.}
 
 @menu
 * File Name Components::  The directory part of a file name, and the rest.

=== modified file 'etc/NEWS'
--- a/etc/NEWS  2012-12-07 09:45:03 +0000
+++ b/etc/NEWS  2012-12-27 07:55:14 +0000
@@ -997,14 +997,16 @@
 ** Cygwin builds can use the native MS Windows user interface.
 Pass --with-w32 to configure.  The default remains the X11 interface.
 
++++
 ** Two new functions are available in Cygwin builds:
 `cygwin-convert-file-name-from-windows' and
 `cygwin-convert-file-name-to-windows'.  These functions allow Lisp
 code to access the Cygwin file-name mapping machinery to convert
 between Cygwin and Windows-native file and directory names.
 
+---
 ** When invoked with the -nw switch to run on the Windows text-mode terminal,
-Emacs now supports mouse highlight, help-echo (in the echo area), and
+Emacs now supports `mouse-highlight', help-echo (in the echo area), and
 `mouse-autoselect-window'.
 
 +++

=== modified file 'src/ChangeLog'
--- a/src/ChangeLog     2012-12-24 16:15:13 +0000
+++ b/src/ChangeLog     2012-12-27 07:55:14 +0000
@@ -1,3 +1,8 @@
+2012-12-27  Glenn Morris  <address@hidden>
+
+       * cygw32.c (Fcygwin_convert_file_name_to_windows)
+       (Fcygwin_convert_file_name_from_windows): Doc fixes.
+
 2012-12-24  Eli Zaretskii  <address@hidden>
 
        * fileio.c (file_name_as_directory, directory_file_name): Accept

=== modified file 'src/cygw32.c'
--- a/src/cygw32.c      2012-11-20 19:28:53 +0000
+++ b/src/cygw32.c      2012-12-27 07:55:14 +0000
@@ -110,23 +110,25 @@
        Fcygwin_convert_file_name_to_windows,
        Scygwin_convert_file_name_to_windows,
        1, 2, 0,
-       doc: /* Convert PATH to a Windows path.  If ABSOLUTE-P is
-non-nil, return an absolute path.*/)
-  (Lisp_Object path, Lisp_Object absolute_p)
+       doc: /* Convert a Cygwin file name FILE to a Windows-style file name.
+If ABSOLUTE-P is non-nil, return an absolute file name.
+For the reverse operation, see `cygwin-convert-file-name-from-windows'.  */)
+  (Lisp_Object file, Lisp_Object absolute_p)
 {
   return from_unicode (
-    conv_filename_to_w32_unicode (path, EQ (absolute_p, Qnil) ? 0 : 1));
+    conv_filename_to_w32_unicode (file, EQ (absolute_p, Qnil) ? 0 : 1));
 }
 
 DEFUN ("cygwin-convert-file-name-from-windows",
        Fcygwin_convert_file_name_from_windows,
        Scygwin_convert_file_name_from_windows,
        1, 2, 0,
-       doc: /* Convert a Windows path to a Cygwin path.  If ABSOLUTE-P
-is non-nil, return an absolute path.*/)
-  (Lisp_Object path, Lisp_Object absolute_p)
+       doc: /* Convert a Windows-style file name FILE to a Cygwin file name.
+If ABSOLUTE-P is non-nil, return an absolute file name.
+For the reverse operation, see `cygwin-convert-file-name-to-windows'.  */)
+  (Lisp_Object file, Lisp_Object absolute_p)
 {
-  return conv_filename_from_w32_unicode (to_unicode (path, &path),
+  return conv_filename_from_w32_unicode (to_unicode (file, &file),
                                          EQ (absolute_p, Qnil) ? 0 : 1);
 }
 


reply via email to

[Prev in Thread] Current Thread [Next in Thread]